@@ -1,11 +1,8 @@
-# -*- coding: utf-8 -*-
-#
 import numpy
 import pytest
 
-import meshio
-
 import helpers
+import meshio
 
 lxml = pytest.importorskip("lxml")
 
@@ -20,8 +17,8 @@ lxml = pytest.importorskip("lxml")
         helpers.add_cell_data(helpers.tri_mesh, 1, dtype=numpy.int32),
     ],
 )
-def test_io(mesh):
-    helpers.write_read(meshio.dolfin_io.write, meshio.dolfin_io.read, mesh, 1.0e-15)
+def test_dolfin(mesh):
+    helpers.write_read(meshio._dolfin.write, meshio._dolfin.read, mesh, 1.0e-15)
     return
 
 
