@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
-#
 import pytest
 
-import meshio
-
 import helpers
+import meshio
 
 
 @pytest.mark.parametrize("mesh", [helpers.tri_mesh])
@@ -18,7 +15,7 @@ import helpers
 )
 def test_stl(mesh, write_binary, tol):
     def writer(*args, **kwargs):
-        return meshio.stl_io.write(*args, write_binary=write_binary, **kwargs)
+        return meshio._stl.write(*args, write_binary=write_binary, **kwargs)
 
-    helpers.write_read(writer, meshio.stl_io.read, mesh, tol)
+    helpers.write_read(writer, meshio._stl.read, mesh, tol)
     return
